"""

    Non-ASCII character handler for RTF documents

    Copyright 2006 Mikko Ohtamaa

"""

from types import UnicodeType, StringTypes
from StringIO import StringIO
    
def encodeText(text, source_encoding="UTF-8"):
    """ Encodes a text for RTF
    
    Takes in text with given source encoding and
    spits out 7-bit ASCII string encoded propeply
    for RTF.
    
    Non-ascii characters must be encoded using
    unicode \u123 syntax.
            
    @param text Source string or string-like object (str() is called for it)
    @param source_encoding Source string encoding, if source string is not unicode string
    
    @return Encoded text in 7-bit ASCII
    """
    
    # RTF encoded characters
    #output_characters = []
    
    if type(text) != UnicodeType:
        if type(text) not in StringTypes:
            text = str(text)
        unicode_text = unicode(text, source_encoding)
    else:
        unicode_text = text
    
    buffer = StringIO()
    
    for c in unicode_text:
        if ord(c) < 128:
            # Convert to non-unicode character
            buffer.write(chr(ord(c)))
        else:
            # Convert to unicode presentation
            buffer.write("\\u" + str(ord(c)))
                    
    return buffer.getvalue()
    
        
        
        